'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _fs = require('fs');

var _fsExtra = require('fs-extra');

var _chalk = require('chalk');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _crossSpawn = require('cross-spawn');

var _crossSpawn2 = _interopRequireDefault(_crossSpawn);

var _projectSettings = require('../webpack/projectSettings');

var _utilities = require('../utilities');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-underscore-dangle */
var template = global.__devToolkitCommandOptions.template || '';
var projectName = global.__devToolkitCommandOptions.projectName || 'my_app';
var skipComments = global.__devToolkitCommandOptions.skipComments || false;

var getTemplatesList = function getTemplatesList(_ref) {
  var folder = _ref.folder;

  var onlyDirectories = function onlyDirectories(file) {
    return (0, _fs.statSync)(_path2.default.join(folder, file)).isDirectory();
  };
  return (0, _fs.readdirSync)(_projectSettings.generatedTemplates).filter(onlyDirectories);
};
var templatesList = getTemplatesList({ folder: _projectSettings.generatedTemplates });
var templateExists = templatesList.indexOf(template) > -1;
var templateName = templateExists ? template : _projectSettings.defaultTemplate;
var isDefaultTemplate = templateName === _projectSettings.defaultTemplate;

if (template && !templateExists) {
  (0, _utilities.log)({ type: 'warning', message: 'template files for \'' + template + '\' don\'t exist.' });
  (0, _utilities.log)({ message: 'You can use one of the following templates:' });
  templatesList.forEach(function (name) {
    return (0, _utilities.log)({ message: '\u2022 ' + name });
  });
  (0, _utilities.log)({
    message: '\nProject will be initialized using default template files (' + _projectSettings.defaultTemplate + ').',
    useSeparator: true
  });
}

var inputFolder = _path2.default.resolve(skipComments ? _projectSettings.generatedTemplatesWithoutComments : _projectSettings.generatedTemplates, templateName);
var projectFolder = _path2.default.resolve(process.cwd(), projectName);

(0, _fsExtra.ensureDirSync)(projectFolder);
(0, _fsExtra.copySync)(inputFolder, projectFolder);

var pkgPath = _path2.default.resolve(projectFolder, 'package.json');
Promise.resolve().then(function () {
  return require('' + pkgPath);
}).then(function (pkg) {
  // Add name to generated project
  (0, _fsExtra.writeJson)(pkgPath, _extends({}, pkg, { name: projectName, description: projectName }), { spaces: 2 }).then(function () {
    (0, _utilities.log)({ message: 'Created project using ' + (0, _chalk.white)(templateName) + ' template in:' });
    (0, _utilities.log)({ message: projectFolder + '\n' });

    if (isDefaultTemplate) {
      _utilities.spinner.start({ message: 'Installing NPM Dependencies for ' + (0, _chalk.white)(projectName) });
    } else {
      (0, _utilities.log)({ message: 'Installing NPM Dependencies for ' + (0, _chalk.white)(projectName) + '\u2026\n' });
    }

    var spawnOptions = isDefaultTemplate ? { cwd: projectFolder } : {
      cwd: projectFolder,
      detached: true,
      stdio: 'inherit'
    };

    (0, _crossSpawn2.default)('npm', ['install'], spawnOptions).on('close', function (code) {
      if (isDefaultTemplate) {
        _utilities.spinner.stop();
      } else {
        (0, _utilities.log)({ message: ' ' });
      }

      if (code === 0) {
        (0, _utilities.log)({ type: 'success', message: 'Dependencies for ' + projectName + ' have been installed.' });
        (0, _utilities.log)({
          message: 'Get started by running `' + (0, _chalk.white)('cd ' + projectName + ' && npm run dev') + '`',
          useSeparator: true
        });
      } else {
        (0, _utilities.log)({ type: 'warning', message: 'Failed to install Dependencies for ' + projectName + '.' });
      }
    });
  }).catch(function (error) {
    (0, _utilities.log)({ type: 'warning', message: 'Failed create project with name ' + projectName + '.', error: error });
  });
});