'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _webpack = require('webpack');

var _webpack2 = _interopRequireDefault(_webpack);

var _webpackDevMiddleware = require('webpack-dev-middleware');

var _webpackDevMiddleware2 = _interopRequireDefault(_webpackDevMiddleware);

var _webpackHotMiddleware = require('webpack-hot-middleware');

var _webpackHotMiddleware2 = _interopRequireDefault(_webpackHotMiddleware);

var _projectSettings = require('../webpack/projectSettings');

var _config = require('../webpack/config');

var _config2 = _interopRequireDefault(_config);

var _utilities = require('../utilities');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _utilities.bootstrap)().then(function (_ref) {
  var server = _ref.server,
      userSettings = _ref.userSettings;

  var webpackAssets = {};
  var config = (0, _config2.default)({
    creatingBuild: false,
    getWebpackAssets: function getWebpackAssets(assets) {
      webpackAssets = assets;
      return JSON.stringify(assets);
    },
    userSettings: userSettings
  });

  (0, _utilities.log)({ message: 'Starting Webpack…' });

  // Compile with middleware for hot-reloading
  var compiler = (0, _webpack2.default)(_extends({}, config, {
    devtool: 'source-map',
    entry: _extends({}, config.entry, {
      app: ['webpack-hot-middleware/client'].concat(config.entry.app)
    })
  }));

  (0, _utilities.log)({ message: 'Compiling initial bundle…\n' });

  var webpackDevMiddlewareInstance = (0, _webpackDevMiddleware2.default)(compiler, {
    noInfo: true,
    publicPath: config.output.publicPath
  });
  var webpackHotMiddlewareInstance = (0, _webpackHotMiddleware2.default)(compiler);

  webpackDevMiddlewareInstance.waitUntilValid(function () {
    (0, _utilities.log)({ message: '\n✨  Initial compilation has finished.', type: 'success' });

    (0, _utilities.log)({ message: 'Attaching dev-middleware & hot-middleware…' });
    try {
      server.express.use(webpackDevMiddlewareInstance);
      server.express.use(webpackHotMiddlewareInstance);
    } catch (error) {
      (0, _utilities.help)({
        displayedWhen: server && !server.express,
        warning: 'Your server needs a `this.express` to be set for attaching webpack middleware.',
        instruction: 'Example: `constructor() { this.express = express(); }`',
        link: '/dev-toolkit#custom-server',
        error: error
      });
    }

    (0, _utilities.log)({ message: 'Starting your Server App…\n', useSeparator: true });
    try {
      server.start({ assets: webpackAssets, buildFolder: _projectSettings.buildFolder });
    } catch (error) {
      (0, _utilities.help)({
        displayedWhen: server && typeof server.start !== 'function',
        warning: 'Your server needs a `start`-method.',
        instruction: 'Example: `start({ assets }) { this.express.listen(2000); }`',
        link: '/dev-toolkit#custom-server',
        error: error
      });
    }
  });
});