import express from 'express';
import expressHandlebars from 'express-handlebars';
import path from 'path';
import fs from 'fs';
import React from 'react';
import { renderToString } from 'react-dom/server';
import { isDev } from 'dev-toolkit/settings';

const serverPort = process.env.SERVER_PORT || 3000;
const serverViews = path.resolve(process.cwd(), 'src/server/views');
const rootComponentPath = path.resolve(process.cwd(), 'src/client/RootComponent');

export default new class {
  constructor() {
    this.express = express();

    this.handlebarsInstance = expressHandlebars.create();

    this.express.engine('hbs', this.handlebarsInstance.engine);
    this.express.set('views', serverViews).set('view engine', 'hbs');
  }

  start({ assets, buildFolder }) {
    this.express.get('/health', (req, res) => res.send('OK'));

    if (isDev) {
      this.express.use((req, res) =>
        res.status(200).render('template', { assets, renderedHtml: '' })
      );
    } else {
      this.express.use(express.static(buildFolder));
    }

    this.serverInstance = this.express.listen(serverPort, () => {
      console.log(`Server is listening on port ${serverPort}`);
    });
  }

  preRender({ assets, buildFolder }) {
    return new Promise((resolve, reject) => {
      import(rootComponentPath).then(module => {
        const RootComponent = module.default;
        this.handlebarsInstance
          .render(path.join(serverViews, 'template.hbs'), {
            assets,
            renderedHtml: renderToString(<RootComponent />),
          })
          .then(html => {
            fs.writeFile(
              path.join(buildFolder, 'index.html'),
              html,
              error => (error ? reject(error) : resolve())
            );
          });
      });
    });
  }
}();
