'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _fsExtra = require('fs-extra');

var _log = require('../log');

var _log2 = _interopRequireDefault(_log);

var _projectSettings = require('../../webpack/projectSettings');

var _defineGlobalDevToolkitSettings = require('./defineGlobalDevToolkitSettings');

var _defineGlobalDevToolkitSettings2 = _interopRequireDefault(_defineGlobalDevToolkitSettings);

var _extractedSharedEnvs = require('./extractedSharedEnvs');

var _extractedSharedEnvs2 = _interopRequireDefault(_extractedSharedEnvs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function () {
  // 1) Get User settings from a specified file
  // ----
  var settingsExist = (0, _fsExtra.pathExistsSync)(_projectSettings.userSettingsPath);
  if (settingsExist) (0, _log2.default)({ message: 'Using settings from `dev-toolkit.config.js`' });
  // We're expecting a classic Node.js module declared with `module.exports`
  // NOTE: Using `require` here is necessary so that using settings with an import like
  //       `import { sharedEnvs} from 'dev-toolkit/settings'` doesn't become an async dependency
  // eslint-disable-next-line import/no-dynamic-require, global-require
  var userSettings = settingsExist ? require(_projectSettings.userSettingsPath) : {};

  // 2) Format settings & generate a safe final version for consumption via node and webpack
  // ----
  var webpack = userSettings.webpack || {};
  var devToolkit = userSettings.devToolkit || {};
  var sharedEnvs = _extends({}, (0, _extractedSharedEnvs2.default)({
    withEnvs: devToolkit.sharedEnvs && Array.isArray(devToolkit.sharedEnvs) ? devToolkit.sharedEnvs : [],
    fromEnvs: process.env
  }), {
    // make NODE_ENV always available
    NODE_ENV: process.env.NODE_ENV
  });
  var finalSettings = {
    webpack: {
      loaders: webpack.loaders && typeof webpack.loaders === 'function' ? webpack.loaders : function () {
        return [];
      },
      plugins: webpack.plugins && typeof webpack.plugins === 'function' ? webpack.plugins : function () {
        return [];
      },
      customize: webpack.customize && typeof webpack.customize === 'function' ? webpack.customize : function (config) {
        return config;
      }
    },
    devToolkit: {
      usePreRender: typeof devToolkit.usePreRender === 'boolean' ? devToolkit.usePreRender : true,
      sharedEnvs: sharedEnvs
    }
  };

  // 3) Define settings in Node so we can use `dev-toolkit/settings` both on the client & server
  // ----
  (0, _defineGlobalDevToolkitSettings2.default)({ settings: finalSettings.devToolkit });
  return finalSettings;
};