'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _help = require('./help');

var _help2 = _interopRequireDefault(_help);

var _log = require('./log');

var _log2 = _interopRequireDefault(_log);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (_ref) {
  var server = _ref.server,
      webpackAssets = _ref.webpackAssets,
      buildFolder = _ref.buildFolder;
  return new Promise(function (resolve) {
    (0, _log2.default)({ message: 'Rendering html using Server App… ', useSeparator: true });
    (0, _help2.default)({
      displayedWhen: server && typeof server.preRender !== 'function',
      warning: 'Your server needs a `preRender`-method to create a build.',
      instruction: 'Example: `preRender({ assets, buildFolder }) { return new Promise(() => { ... }); }`',
      link: '/dev-toolkit#custom-server'
    });
    var renderPromise = server.preRender({ assets: webpackAssets, buildFolder: buildFolder });
    (0, _help2.default)({
      displayedWhen: typeof renderPromise.then !== 'function',
      warning: "The server `preRender`-method must return a Promise to say it's finished.",
      instruction: 'Example: `preRender({ assets, buildFolder }) { return new Promise(() => { ... }); }`',
      link: '/dev-toolkit#custom-server'
    });
    renderPromise.then(resolve).catch(function (buildError) {
      return (0, _log2.default)({ error: buildError });
    });
  });
};